@@ -268,14 +268,9 @@ knitr::opts_chunk$set(echo=FALSE, message=FALSE, warning=FALSE, comment=NA, dev=
 # warnings
 warning_bargraph  <- "You may prefer a 'histogram' instead of a 'bargraph'."
 warning_general   <- "I'm so sorry because something went wrong :("
-warning_pandoc    <- "'brinton' requires Pandoc v < 1.12.3 (https://pandoc.org/)."
+warning_pandoc    <- "Warning: I'm so sorry but 'brinton' requires Pandoc v >= 1.12.3 (https://pandoc.org/)."
 warning_color     <- "Color argument accepts only 'black', 'bw' or 'color' values."
 warning_coord     <- "Coord argument accepts only 'xy' or 'yx' values."
 warning_long      <- "It seems that there are too many levels for some categorical variable."
-warning_wp_dt     <- "Wideplot's 'datetime' available graphics are 'linegraph', 'pointgraph' and 'blank'."
-warning_wp_lc     <- "Wideplot's 'logical' available graphics are 'linegraph', 'pointgraph' and 'blank'."
-warning_wp_of     <- "Wideplot's 'ordered factor' available graphics are 'linegraph', 'pointgraph', 'bargraph' and 'blank'."
-warning_wp_ft     <- "Wideplot's 'factor' available graphics are 'linegraph', 'pointgraph', 'bargraph', 'reorderedbargraph' and 'blank'."
-warning_wp_nu     <- "Wideplot's 'numeric' available graphics are 'linegraph', 'pointgraph', 'histogram', 'densityplot', '3uniaxial', 'qqplot' and 'blank'."
-warning_wp_ch     <- "Wideplot's 'character' available graphics are 'linegraph', 'pointgraph', 'bargraph', 'reorderedbargraph' and 'blank'."
-warning_wp_dc     <- "Available datatypes are 'datetime', 'logical', 'factor', 'ordered', 'integer', 'double' and 'character'"
+warning_wrong     <- "Apparently something is wrong."
+warning_wp_dc     <- "Available datatypes are 'datetime', 'logical', 'factor', 'ordered', 'numeric' and 'character'"
